@@ -1,11 +1,12 @@
 import os
 import re
+import argparse
 import textwrap
 from .project import Project
 
 
 class ReferenceArchitectureOption:
-    choices = ['EDB-RA-1', 'EDB-RA-2', 'EDB-RA-3']
+    choices = ['EDB-RA-1', 'EDB-RA-2', 'EDB-RA-3', 'DBT-2', 'HammerDB-TPROC-C']
 
     default = 'EDB-RA-1'
     help = textwrap.dedent("""
@@ -14,28 +15,42 @@ class ReferenceArchitectureOption:
         monitoring server, EDB-RA-2 for a 3 Postgres nodes deployment with
         quorum base synchronous replication and automatic failover, one backup
         server and one PEM monitoring server, EDB-RA-3 for extending EDB-RA-2
-        with 3 PgPoolII nodes. Default:
-        %(default)s
+        with 3 PgPoolII nodes, DBT-2 for benchmarking 3-tier client-server
+        architectures with an OLTP workload, and HammerDB-TPROC-C for
+        benchmarking 2-tier client-server architectures with an OLTP workload.
+        Default: %(default)s
     """)
 
 
-class ReferenceArchitectureOptionAWS:
-    choices = ['EDB-RA-1', 'EDB-RA-2', 'EDB-RA-3', 'HammerDB-TPROC-C']
+class POTReferenceArchitectureOption:
+    choices = ['EDB-RA']
 
-    default = 'EDB-RA-1'
+    default = 'EDB-RA'
     help = textwrap.dedent("""
-        Reference architecture code name. Allowed values are: EDB-RA-1 for a
-        single Postgres node deployment with one backup server and one PEM
-        monitoring server, EDB-RA-2 for a 3 Postgres nodes deployment with
-        quorum base synchronous replication and automatic failover, one backup
-        server and one PEM monitoring server, EDB-RA-3 for extending EDB-RA-2
-        with 3 PgPoolII nodes, and HammerDB-TPROC-C for benchmarking 2-tier
-        client-server architectures with and OLTP workload. Default:
-        %(default)s
+        Reference architecture code name. Allowed values are: EDB-RA for
+        a 3 Postgres nodes deployment with quorum base synchronous replication
+        and automatic failover, one backup server and one PEM monitoring
+        server.
+        Default: %(default)s
+    """)
+
+class AWSPOTReferenceArchitectureOption:
+    choices = ['EDB-RA', 'EDB-Always-On']
+
+    default = 'EDB-RA'
+    help = textwrap.dedent("""
+        Reference architecture code name. Allowed values are: EDB-RA for
+        a 3 Postgres nodes deployment with quorum base synchronous replication
+        and automatic failover, one backup server and one PEM monitoring
+        server, EDB-Always-On for deployment 6 Postgres nodes and one witness node
+        with BDR EE, two backup servers, 4 Pgbouncer/HAproxy servers and
+        one PEM monitoring server.
+        Default: %(default)s
     """)
 
 
-class ReferenceArchitectureOptionRDS:
+
+class ReferenceArchitectureOptionDBaaS:
     choices = ['HammerDB-DBaaS']
     default = 'HammerDB-DBaaS'
     help = textwrap.dedent("""
@@ -46,10 +61,6 @@ class ReferenceArchitectureOptionRDS:
     """)
 
 
-class ReferenceArchitectureOptionAzure(ReferenceArchitectureOptionAWS):
-    pass
-
-
 class OSOption:
     choices = ['CentOS7', 'CentOS8', 'RedHat7', 'RedHat8']
     default = 'CentOS8'
@@ -59,6 +70,20 @@ class OSOption:
     """)
 
 
+class VMWareOSOption:
+    choices = ['CentOS8']
+    default = 'CentOS8'
+    help = textwrap.dedent("""
+        Operating system. Allowed values are: CentOS8. Default: %(default)s
+    """)
+
+class VirtualBoxOSOption:
+    choices = ['CentOS8']
+    default = 'CentOS8'
+    help = textwrap.dedent("""
+        Operating system. Allowed values are: CentOS8. Default: %(default)s
+    """)
+
 class PgVersionOption:
     choices = ['11', '12', '13']
     default = '13'
@@ -67,12 +92,54 @@ class PgVersionOption:
         Default: %(default)s
     """)
 
+class POTPgVersionOption:
+    choices = ['13']
+    default = '13'
+    help = textwrap.dedent("""
+        EPAS version. Allowed values are: 13.
+        Default: %(default)s
+    """)
+
+
+class PgVersionOptionAzureDB:
+    choices = ['11']
+    default = '11'
+    help = textwrap.dedent("""
+        Azure Database for PostgreSQL version. Allowed values are: 11.
+        Default: %(default)s
+    """)
+
 
 class EFMVersionOption:
-    choices = ['3.10', '4.0', '4.1']
-    default = '4.1'
+    choices = ['3.10', '4.0', '4.1', '4.2']
+    default = '4.2'
     help = textwrap.dedent("""
-        EDB Failover Manager version. Allowed values are: 3.10, 4.0 and 4.1.
+        EDB Failover Manager version. Allowed values are: 3.10, 4.0, 4.1 and 4.2.
+        Default: %(default)s
+    """)
+
+class EFMVersionOptionVMWare:
+    choices = ['3.10', '4.0', '4.1', '4.2']
+    default = '4.2'
+    help = textwrap.dedent("""
+        EDB Failover Manager version. Allowed values are: 3.10, 4.0, 4.1 and 4.2.
+        Default: %(default)s
+    """)
+
+class EFMVersionOptionVirtualBox:
+    choices = ['3.10', '4.0', '4.1', '4.2']
+    default = '4.2'
+    help = textwrap.dedent("""
+        EDB Failover Manager version. Allowed values are: 3.10, 4.0, 4.1 and 4.2.
+        Default: %(default)s
+    """)
+
+
+class UseHostnameOption:
+    choices = [True, False]
+    default = True
+    help = textwrap.dedent("""
+        Use hostnames for connectivity between servers.
         Default: %(default)s
     """)
 
@@ -87,15 +154,66 @@ class PgTypeOption:
     """)
 
 
-class PgTypeOptionRDS:
-    choices = ['RDS']
-    default = 'RDS'
+class POTPgTypeOption:
+    choices = ['EPAS']
+    default = 'EPAS'
     help = textwrap.dedent("""
-        Postgres engine type. Allowed values are: RDS for AWS RDS.  Default:
+        Postgres engine type. Allowed values are: EPAS for
+        EDB Postgres Advanced Server. Default:
         %(default)s
     """)
 
 
+class PgTypeOptionRDS:
+    choices = ['DBaaS']
+    default = 'DBaaS'
+    help = textwrap.dedent("""
+        Postgres engine type. Allowed values are: DBaaS for AWS RDS.  Default:
+        %(default)s
+    """)
+
+
+class PgTypeOptionAzureDB:
+    choices = ['DBaaS']
+    default = 'DBaaS'
+    help = textwrap.dedent("""
+        Postgres engine type. Allowed values are: DBaaS for Azure Database.
+        Default: %(default)s
+    """)
+
+class MemSizeOptionsVMWare:
+    choices = ['2048', '3072', '4096', '5120']
+    default = '2048'
+    help = textwrap.dedent("""
+        Memory size options. Allowed values are: {choices} for VMWare.
+        Default: %(default)s
+    """)
+
+class MemSizeOptionsVirtualBox:
+    choices = ['2048', '3072', '4096', '5120']
+    default = '2048'
+    help = textwrap.dedent("""
+        Memory size options. Allowed values are: {choices} for VirtualBox.
+        Default: %(default)s
+    """)
+
+class CPUCountOptionsVMWare:
+    choices = ['1', '2']
+    default = '1'
+    help = textwrap.dedent("""
+        CPU Count options. Allowed values are: 1, 2 for VMWare.
+        Default: %(default)s
+    """)
+
+class CPUCountOptionsVirtualBox:
+    choices = ['1', '2']
+    default = '1'
+    help = textwrap.dedent("""
+        CPU Count options. Allowed values are: 1, 2 for VirtualBox.
+        Default: %(default)s
+    """)
+
+
 class SSHPubKeyOption:
 
     help = textwrap.dedent("""
